/****************************************************************************
** Meta object code from reading C++ file 'plasmawindowmanagement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.2/src/client/plasmawindowmanagement.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasmawindowmanagement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client22PlasmaWindowManagementE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PlasmaWindowManagement::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client22PlasmaWindowManagementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PlasmaWindowManagement",
        "interfaceAboutToBeReleased",
        "",
        "interfaceAboutToBeDestroyed",
        "showingDesktopChanged",
        "windowCreated",
        "KWayland::Client::PlasmaWindow*",
        "window",
        "activeWindowChanged",
        "removed",
        "stackingOrderUuidsChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'interfaceAboutToBeReleased'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interfaceAboutToBeDestroyed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showingDesktopChanged'
        QtMocHelpers::SignalData<void(bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'windowCreated'
        QtMocHelpers::SignalData<void(KWayland::Client::PlasmaWindow *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Signal 'activeWindowChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stackingOrderUuidsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmaWindowManagement, qt_meta_tag_ZN8KWayland6Client22PlasmaWindowManagementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PlasmaWindowManagement::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client22PlasmaWindowManagementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client22PlasmaWindowManagementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client22PlasmaWindowManagementE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PlasmaWindowManagement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaWindowManagement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->interfaceAboutToBeReleased(); break;
        case 1: _t->interfaceAboutToBeDestroyed(); break;
        case 2: _t->showingDesktopChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->windowCreated((*reinterpret_cast<std::add_pointer_t<KWayland::Client::PlasmaWindow*>>(_a[1]))); break;
        case 4: _t->activeWindowChanged(); break;
        case 5: _t->removed(); break;
        case 6: _t->stackingOrderUuidsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::PlasmaWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindowManagement::*)()>(_a, &PlasmaWindowManagement::interfaceAboutToBeReleased, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindowManagement::*)()>(_a, &PlasmaWindowManagement::interfaceAboutToBeDestroyed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindowManagement::*)(bool )>(_a, &PlasmaWindowManagement::showingDesktopChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindowManagement::*)(KWayland::Client::PlasmaWindow * )>(_a, &PlasmaWindowManagement::windowCreated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindowManagement::*)()>(_a, &PlasmaWindowManagement::activeWindowChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindowManagement::*)()>(_a, &PlasmaWindowManagement::removed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindowManagement::*)()>(_a, &PlasmaWindowManagement::stackingOrderUuidsChanged, 6))
            return;
    }
}

const QMetaObject *KWayland::Client::PlasmaWindowManagement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PlasmaWindowManagement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client22PlasmaWindowManagementE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PlasmaWindowManagement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PlasmaWindowManagement::interfaceAboutToBeReleased()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWayland::Client::PlasmaWindowManagement::interfaceAboutToBeDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWayland::Client::PlasmaWindowManagement::showingDesktopChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KWayland::Client::PlasmaWindowManagement::windowCreated(KWayland::Client::PlasmaWindow * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KWayland::Client::PlasmaWindowManagement::activeWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KWayland::Client::PlasmaWindowManagement::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KWayland::Client::PlasmaWindowManagement::stackingOrderUuidsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client12PlasmaWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PlasmaWindow::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client12PlasmaWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PlasmaWindow",
        "titleChanged",
        "",
        "appIdChanged",
        "activeChanged",
        "fullscreenChanged",
        "keepAboveChanged",
        "keepBelowChanged",
        "minimizedChanged",
        "maximizedChanged",
        "onAllDesktopsChanged",
        "demandsAttentionChanged",
        "closeableChanged",
        "minimizeableChanged",
        "maximizeableChanged",
        "fullscreenableChanged",
        "skipTaskbarChanged",
        "skipSwitcherChanged",
        "iconChanged",
        "shadeableChanged",
        "shadedChanged",
        "movableChanged",
        "resizableChanged",
        "virtualDesktopChangeableChanged",
        "unmapped",
        "parentWindowChanged",
        "geometryChanged",
        "resourceNameChanged",
        "plasmaVirtualDesktopEntered",
        "id",
        "plasmaVirtualDesktopLeft",
        "plasmaActivityEntered",
        "plasmaActivityLeft",
        "applicationMenuChanged",
        "clientGeometryChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'appIdChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keepAboveChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keepBelowChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimizedChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximizedChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onAllDesktopsChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'demandsAttentionChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeableChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'minimizeableChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maximizeableChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreenableChanged'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipTaskbarChanged'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'skipSwitcherChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadeableChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shadedChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'movableChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resizableChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'virtualDesktopChangeableChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'unmapped'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parentWindowChanged'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryChanged'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resourceNameChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'plasmaVirtualDesktopEntered'
        QtMocHelpers::SignalData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Signal 'plasmaVirtualDesktopLeft'
        QtMocHelpers::SignalData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Signal 'plasmaActivityEntered'
        QtMocHelpers::SignalData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Signal 'plasmaActivityLeft'
        QtMocHelpers::SignalData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 },
        }}),
        // Signal 'applicationMenuChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clientGeometryChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmaWindow, qt_meta_tag_ZN8KWayland6Client12PlasmaWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PlasmaWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client12PlasmaWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client12PlasmaWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client12PlasmaWindowE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PlasmaWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->titleChanged(); break;
        case 1: _t->appIdChanged(); break;
        case 2: _t->activeChanged(); break;
        case 3: _t->fullscreenChanged(); break;
        case 4: _t->keepAboveChanged(); break;
        case 5: _t->keepBelowChanged(); break;
        case 6: _t->minimizedChanged(); break;
        case 7: _t->maximizedChanged(); break;
        case 8: _t->onAllDesktopsChanged(); break;
        case 9: _t->demandsAttentionChanged(); break;
        case 10: _t->closeableChanged(); break;
        case 11: _t->minimizeableChanged(); break;
        case 12: _t->maximizeableChanged(); break;
        case 13: _t->fullscreenableChanged(); break;
        case 14: _t->skipTaskbarChanged(); break;
        case 15: _t->skipSwitcherChanged(); break;
        case 16: _t->iconChanged(); break;
        case 17: _t->shadeableChanged(); break;
        case 18: _t->shadedChanged(); break;
        case 19: _t->movableChanged(); break;
        case 20: _t->resizableChanged(); break;
        case 21: _t->virtualDesktopChangeableChanged(); break;
        case 22: _t->unmapped(); break;
        case 23: _t->parentWindowChanged(); break;
        case 24: _t->geometryChanged(); break;
        case 25: _t->resourceNameChanged(); break;
        case 26: _t->plasmaVirtualDesktopEntered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->plasmaVirtualDesktopLeft((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->plasmaActivityEntered((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 29: _t->plasmaActivityLeft((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 30: _t->applicationMenuChanged(); break;
        case 31: _t->clientGeometryChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::titleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::appIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::activeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::fullscreenChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::keepAboveChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::keepBelowChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::minimizedChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::maximizedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::onAllDesktopsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::demandsAttentionChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::closeableChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::minimizeableChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::maximizeableChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::fullscreenableChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::skipTaskbarChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::skipSwitcherChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::iconChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::shadeableChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::shadedChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::movableChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::resizableChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::virtualDesktopChangeableChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::unmapped, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::parentWindowChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::geometryChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::resourceNameChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)(const QString & )>(_a, &PlasmaWindow::plasmaVirtualDesktopEntered, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)(const QString & )>(_a, &PlasmaWindow::plasmaVirtualDesktopLeft, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)(const QString & )>(_a, &PlasmaWindow::plasmaActivityEntered, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)(const QString & )>(_a, &PlasmaWindow::plasmaActivityLeft, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::applicationMenuChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaWindow::*)()>(_a, &PlasmaWindow::clientGeometryChanged, 31))
            return;
    }
}

const QMetaObject *KWayland::Client::PlasmaWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PlasmaWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client12PlasmaWindowE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PlasmaWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 32)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 32;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 32)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 32;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PlasmaWindow::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWayland::Client::PlasmaWindow::appIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWayland::Client::PlasmaWindow::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KWayland::Client::PlasmaWindow::fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KWayland::Client::PlasmaWindow::keepAboveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KWayland::Client::PlasmaWindow::keepBelowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KWayland::Client::PlasmaWindow::minimizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KWayland::Client::PlasmaWindow::maximizedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KWayland::Client::PlasmaWindow::onAllDesktopsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KWayland::Client::PlasmaWindow::demandsAttentionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KWayland::Client::PlasmaWindow::closeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KWayland::Client::PlasmaWindow::minimizeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KWayland::Client::PlasmaWindow::maximizeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KWayland::Client::PlasmaWindow::fullscreenableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KWayland::Client::PlasmaWindow::skipTaskbarChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KWayland::Client::PlasmaWindow::skipSwitcherChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KWayland::Client::PlasmaWindow::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KWayland::Client::PlasmaWindow::shadeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KWayland::Client::PlasmaWindow::shadedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KWayland::Client::PlasmaWindow::movableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KWayland::Client::PlasmaWindow::resizableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KWayland::Client::PlasmaWindow::virtualDesktopChangeableChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KWayland::Client::PlasmaWindow::unmapped()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void KWayland::Client::PlasmaWindow::parentWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void KWayland::Client::PlasmaWindow::geometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void KWayland::Client::PlasmaWindow::resourceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void KWayland::Client::PlasmaWindow::plasmaVirtualDesktopEntered(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 26, nullptr, _t1);
}

// SIGNAL 27
void KWayland::Client::PlasmaWindow::plasmaVirtualDesktopLeft(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 27, nullptr, _t1);
}

// SIGNAL 28
void KWayland::Client::PlasmaWindow::plasmaActivityEntered(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void KWayland::Client::PlasmaWindow::plasmaActivityLeft(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1);
}

// SIGNAL 30
void KWayland::Client::PlasmaWindow::applicationMenuChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void KWayland::Client::PlasmaWindow::clientGeometryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client16PlasmaActivationE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PlasmaActivation::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client16PlasmaActivationE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PlasmaActivation",
        "applicationId",
        "",
        "appId",
        "finished"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'applicationId'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'finished'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmaActivation, qt_meta_tag_ZN8KWayland6Client16PlasmaActivationE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PlasmaActivation::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client16PlasmaActivationE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client16PlasmaActivationE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client16PlasmaActivationE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PlasmaActivation::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaActivation *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->applicationId((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->finished(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaActivation::*)(const QString & )>(_a, &PlasmaActivation::applicationId, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaActivation::*)()>(_a, &PlasmaActivation::finished, 1))
            return;
    }
}

const QMetaObject *KWayland::Client::PlasmaActivation::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PlasmaActivation::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client16PlasmaActivationE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PlasmaActivation::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PlasmaActivation::applicationId(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KWayland::Client::PlasmaActivation::finished()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
namespace {
struct qt_meta_tag_ZN8KWayland6Client24PlasmaActivationFeedbackE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PlasmaActivationFeedback::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client24PlasmaActivationFeedbackE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PlasmaActivationFeedback",
        "interfaceAboutToBeReleased",
        "",
        "interfaceAboutToBeDestroyed",
        "removed",
        "activation",
        "KWayland::Client::PlasmaActivation*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'interfaceAboutToBeReleased'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'interfaceAboutToBeDestroyed'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removed'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activation'
        QtMocHelpers::SignalData<void(KWayland::Client::PlasmaActivation *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 5 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlasmaActivationFeedback, qt_meta_tag_ZN8KWayland6Client24PlasmaActivationFeedbackE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PlasmaActivationFeedback::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client24PlasmaActivationFeedbackE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client24PlasmaActivationFeedbackE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client24PlasmaActivationFeedbackE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PlasmaActivationFeedback::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaActivationFeedback *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->interfaceAboutToBeReleased(); break;
        case 1: _t->interfaceAboutToBeDestroyed(); break;
        case 2: _t->removed(); break;
        case 3: _t->activation((*reinterpret_cast<std::add_pointer_t<KWayland::Client::PlasmaActivation*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::PlasmaActivation* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlasmaActivationFeedback::*)()>(_a, &PlasmaActivationFeedback::interfaceAboutToBeReleased, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaActivationFeedback::*)()>(_a, &PlasmaActivationFeedback::interfaceAboutToBeDestroyed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaActivationFeedback::*)()>(_a, &PlasmaActivationFeedback::removed, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlasmaActivationFeedback::*)(KWayland::Client::PlasmaActivation * )>(_a, &PlasmaActivationFeedback::activation, 3))
            return;
    }
}

const QMetaObject *KWayland::Client::PlasmaActivationFeedback::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PlasmaActivationFeedback::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client24PlasmaActivationFeedbackE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::PlasmaActivationFeedback::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::PlasmaActivationFeedback::interfaceAboutToBeReleased()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWayland::Client::PlasmaActivationFeedback::interfaceAboutToBeDestroyed()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWayland::Client::PlasmaActivationFeedback::removed()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KWayland::Client::PlasmaActivationFeedback::activation(KWayland::Client::PlasmaActivation * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
