/* Generated by wayland-scanner 1.25.0 */

/*
 * SPDX-FileCopyrightText: 2012, 2013 Intel Corporation
 *
 * SPDX-License-Identifier: MIT-CMU
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

#ifndef __has_attribute
# define __has_attribute(x) 0  /* Compatibility with non-clang compilers. */
#endif

#if (__has_attribute(visibility) || defined(__GNUC__) && __GNUC__ >= 4)
#define WL_PRIVATE __attribute__ ((visibility("hidden")))
#else
#define WL_PRIVATE
#endif

extern const struct wl_interface wl_seat_interface;
extern const struct wl_interface wl_surface_interface;
extern const struct wl_interface wl_text_input_interface;

static const struct wl_interface *text_types[] = {
	NULL,
	NULL,
	NULL,
	NULL,
	NULL,
	&wl_seat_interface,
	&wl_surface_interface,
	&wl_seat_interface,
	&wl_surface_interface,
	&wl_text_input_interface,
};

static const struct wl_message wl_text_input_requests[] = {
	{ "activate", "oo", text_types + 5 },
	{ "deactivate", "o", text_types + 7 },
	{ "show_input_panel", "", text_types + 0 },
	{ "hide_input_panel", "", text_types + 0 },
	{ "reset", "", text_types + 0 },
	{ "set_surrounding_text", "suu", text_types + 0 },
	{ "set_content_type", "uu", text_types + 0 },
	{ "set_cursor_rectangle", "iiii", text_types + 0 },
	{ "set_preferred_language", "s", text_types + 0 },
	{ "commit_state", "u", text_types + 0 },
	{ "invoke_action", "uu", text_types + 0 },
};

static const struct wl_message wl_text_input_events[] = {
	{ "enter", "o", text_types + 8 },
	{ "leave", "", text_types + 0 },
	{ "modifiers_map", "a", text_types + 0 },
	{ "input_panel_state", "u", text_types + 0 },
	{ "preedit_string", "uss", text_types + 0 },
	{ "preedit_styling", "uuu", text_types + 0 },
	{ "preedit_cursor", "i", text_types + 0 },
	{ "commit_string", "us", text_types + 0 },
	{ "cursor_position", "ii", text_types + 0 },
	{ "delete_surrounding_text", "iu", text_types + 0 },
	{ "keysym", "uuuuu", text_types + 0 },
	{ "language", "us", text_types + 0 },
	{ "text_direction", "uu", text_types + 0 },
};

WL_PRIVATE const struct wl_interface wl_text_input_interface = {
	"wl_text_input", 1,
	11, wl_text_input_requests,
	13, wl_text_input_events,
};

static const struct wl_message wl_text_input_manager_requests[] = {
	{ "create_text_input", "n", text_types + 9 },
};

WL_PRIVATE const struct wl_interface wl_text_input_manager_interface = {
	"wl_text_input_manager", 1,
	1, wl_text_input_manager_requests,
	0, NULL,
};

