/****************************************************************************
** Meta object code from reading C++ file 'datadevice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.2/src/client/datadevice.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'datadevice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client10DataDeviceE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::DataDevice::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client10DataDeviceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::DataDevice",
        "selectionOffered",
        "",
        "KWayland::Client::DataOffer*",
        "selectionCleared",
        "dragEntered",
        "serial",
        "QPointF",
        "relativeToSurface",
        "dragLeft",
        "dragMotion",
        "time",
        "dropped"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'selectionOffered'
        QtMocHelpers::SignalData<void(KWayland::Client::DataOffer *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'selectionCleared'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragEntered'
        QtMocHelpers::SignalData<void(quint32, const QPointF &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'dragLeft'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragMotion'
        QtMocHelpers::SignalData<void(const QPointF &, quint32)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::UInt, 11 },
        }}),
        // Signal 'dropped'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataDevice, qt_meta_tag_ZN8KWayland6Client10DataDeviceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::DataDevice::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client10DataDeviceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client10DataDeviceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client10DataDeviceE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::DataDevice::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataDevice *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->selectionOffered((*reinterpret_cast<std::add_pointer_t<KWayland::Client::DataOffer*>>(_a[1]))); break;
        case 1: _t->selectionCleared(); break;
        case 2: _t->dragEntered((*reinterpret_cast<std::add_pointer_t<quint32>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[2]))); break;
        case 3: _t->dragLeft(); break;
        case 4: _t->dragMotion((*reinterpret_cast<std::add_pointer_t<QPointF>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<quint32>>(_a[2]))); break;
        case 5: _t->dropped(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KWayland::Client::DataOffer* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DataDevice::*)(KWayland::Client::DataOffer * )>(_a, &DataDevice::selectionOffered, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataDevice::*)()>(_a, &DataDevice::selectionCleared, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataDevice::*)(quint32 , const QPointF & )>(_a, &DataDevice::dragEntered, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataDevice::*)()>(_a, &DataDevice::dragLeft, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataDevice::*)(const QPointF & , quint32 )>(_a, &DataDevice::dragMotion, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DataDevice::*)()>(_a, &DataDevice::dropped, 5))
            return;
    }
}

const QMetaObject *KWayland::Client::DataDevice::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::DataDevice::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client10DataDeviceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KWayland::Client::DataDevice::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void KWayland::Client::DataDevice::selectionOffered(KWayland::Client::DataOffer * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KWayland::Client::DataDevice::selectionCleared()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWayland::Client::DataDevice::dragEntered(quint32 _t1, const QPointF & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KWayland::Client::DataDevice::dragLeft()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KWayland::Client::DataDevice::dragMotion(const QPointF & _t1, quint32 _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KWayland::Client::DataDevice::dropped()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
QT_WARNING_POP
