/****************************************************************************
** Meta object code from reading C++ file 'plasmawindowmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../kwayland-6.7.2/src/client/plasmawindowmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plasmawindowmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWayland6Client17PlasmaWindowModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KWayland::Client::PlasmaWindowModel::qt_create_metaobjectdata<qt_meta_tag_ZN8KWayland6Client17PlasmaWindowModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWayland::Client::PlasmaWindowModel",
        "requestActivate",
        "",
        "row",
        "requestClose",
        "requestMove",
        "requestResize",
        "requestEnterVirtualDesktop",
        "id",
        "requestToggleKeepAbove",
        "requestToggleKeepBelow",
        "requestToggleMinimized",
        "requestToggleMaximized",
        "requestToggleFullscreen",
        "setMinimizedGeometry",
        "Surface*",
        "panel",
        "QRect",
        "geom",
        "requestToggleShaded",
        "AdditionalRoles",
        "AppId",
        "IsActive",
        "IsFullscreenable",
        "IsFullscreen",
        "IsMaximizable",
        "IsMaximized",
        "IsMinimizable",
        "IsMinimized",
        "IsKeepAbove",
        "IsKeepBelow",
        "IsOnAllDesktops",
        "IsDemandingAttention",
        "SkipTaskbar",
        "IsShadeable",
        "IsShaded",
        "IsMovable",
        "IsResizable",
        "IsVirtualDesktopChangeable",
        "IsCloseable",
        "Geometry",
        "Pid",
        "SkipSwitcher",
        "VirtualDesktops",
        "Uuid",
        "LastRole"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'requestActivate'
        QtMocHelpers::MethodData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestClose'
        QtMocHelpers::MethodData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestMove'
        QtMocHelpers::MethodData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestResize'
        QtMocHelpers::MethodData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestEnterVirtualDesktop'
        QtMocHelpers::MethodData<void(int, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::QString, 8 },
        }}),
        // Method 'requestToggleKeepAbove'
        QtMocHelpers::MethodData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestToggleKeepBelow'
        QtMocHelpers::MethodData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestToggleMinimized'
        QtMocHelpers::MethodData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestToggleMaximized'
        QtMocHelpers::MethodData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'requestToggleFullscreen'
        QtMocHelpers::MethodData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Method 'setMinimizedGeometry'
        QtMocHelpers::MethodData<void(int, Surface *, const QRect &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { 0x80000000 | 15, 16 }, { 0x80000000 | 17, 18 },
        }}),
        // Method 'requestToggleShaded'
        QtMocHelpers::MethodData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AdditionalRoles'
        QtMocHelpers::EnumData<enum AdditionalRoles>(20, 20, QMC::EnumFlags{}).add({
            {   21, AdditionalRoles::AppId },
            {   22, AdditionalRoles::IsActive },
            {   23, AdditionalRoles::IsFullscreenable },
            {   24, AdditionalRoles::IsFullscreen },
            {   25, AdditionalRoles::IsMaximizable },
            {   26, AdditionalRoles::IsMaximized },
            {   27, AdditionalRoles::IsMinimizable },
            {   28, AdditionalRoles::IsMinimized },
            {   29, AdditionalRoles::IsKeepAbove },
            {   30, AdditionalRoles::IsKeepBelow },
            {   31, AdditionalRoles::IsOnAllDesktops },
            {   32, AdditionalRoles::IsDemandingAttention },
            {   33, AdditionalRoles::SkipTaskbar },
            {   34, AdditionalRoles::IsShadeable },
            {   35, AdditionalRoles::IsShaded },
            {   36, AdditionalRoles::IsMovable },
            {   37, AdditionalRoles::IsResizable },
            {   38, AdditionalRoles::IsVirtualDesktopChangeable },
            {   39, AdditionalRoles::IsCloseable },
            {   40, AdditionalRoles::Geometry },
            {   41, AdditionalRoles::Pid },
            {   42, AdditionalRoles::SkipSwitcher },
            {   43, AdditionalRoles::VirtualDesktops },
            {   44, AdditionalRoles::Uuid },
            {   45, AdditionalRoles::LastRole },
        }),
    };
    return QtMocHelpers::metaObjectData<PlasmaWindowModel, qt_meta_tag_ZN8KWayland6Client17PlasmaWindowModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWayland::Client::PlasmaWindowModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client17PlasmaWindowModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client17PlasmaWindowModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWayland6Client17PlasmaWindowModelE_t>.metaTypes,
    nullptr
} };

void KWayland::Client::PlasmaWindowModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlasmaWindowModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestActivate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->requestClose((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->requestMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->requestResize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->requestEnterVirtualDesktop((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->requestToggleKeepAbove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->requestToggleKeepBelow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->requestToggleMinimized((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->requestToggleMaximized((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->requestToggleFullscreen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->setMinimizedGeometry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Surface*>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3]))); break;
        case 11: _t->requestToggleShaded((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KWayland::Client::PlasmaWindowModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWayland::Client::PlasmaWindowModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWayland6Client17PlasmaWindowModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KWayland::Client::PlasmaWindowModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
